-- IGQ demo
-- zorg @ 2017 § ISC
--[[
	Copyright 2017 zorg
	Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
--]]

local text, gaps, w, h, lens, word, ofss
function love.load()
	local old_lgsetcolor = love.graphics.setColor
	love.graphics.setColor = function(r,g,b,a)
		local _,m,_,_ = love.getVersion()
		if m == 11 then
			old_lgsetcolor(r,g,b,a)
		else
			if type(r) == 'table' then
				r,g,b,a = unpack(r)
			end
			r,g,b,a = r or 1, g or 1, b or 1, a or 1
			old_lgsetcolor(math.floor(r*255), math.floor(g*255), math.floor(b*255), math.floor(a*255))
		end
	end
	local ln, pg = 16, 24
	gaps = {0,pg,pg,pg,pg,pg,pg,pg,pg,pg,pg,pg,ln,pg,pg,ln,pg,pg,pg,pg,pg}
	word = {'story','composition','artwork','thing','project','font','concept','song','painting'}
	text = {
		"Nobody tells this to people who are beginners, I wish someone told me.",
		"All of us who do creative work, we get into it because we have good taste.",
		"But there is this gap.",
		"For the first couple years you make stuff, it’s just not that good.",
		"It’s trying to be good, it has potential, but it’s not.",
		"But your taste, the thing that got you into the game, is still killer.",
		"And your taste is why your work disappoints you.",
		"A lot of people never get past this phase, they quit.",
		"Most people I know who do interesting, creative work went through years of this.",
		"We know our work doesn’t have this special thing that we want it to have.",
		"We all go through this.",
		"And if you are just starting out or you are still in this phase,",
		"you gotta know its normal and the most important thing you can do is do a lot of work.",
		"Put yourself on a deadline so that every week you will finish one %s.",
		"It is only by going through a volume of work that you will close that gap,",
		"and your work will be as good as your ambitions.",
		"And I took longer to figure out how to do this than anyone I’ve ever met.",
		"It’s gonna take awhile.",
		"It’s normal to take awhile.",
		"You’ve just gotta fight your way through.",
	} -- ~Ira Glass.
	lens = {}
	for i=1, #text do
		if i ~= 14 then lens[i] = #text[i] * 8
		else lens[i] = (#text[i] - 2 + math.max(unpack((function() local wl = {}; for i=1, #word do wl[i] = #word[i] end return wl end)()))) * 8
	end end
	w, h = math.max(unpack(lens)), 0
	for i=1, #gaps do h = h + gaps[i] end
	ofss = {} for i=1, #lens do ofss[i] = (w - lens[i]) / 2 end
	love.window.setTitle('Ira Glass Quote')
	love.window.setMode(w+16,h)
	love.graphics.setFont(love.graphics.newFont('FSEX300.ttf', 16))
end
local a,n = 0.0,1
local tick = 1/10
local timer, sint = 0.0, 0.0
function love.update(dt)
	timer = timer + dt
	sint = sint + dt
	if timer > tick then
		timer = timer - tick
		local b = a
		while b == a do
			b = math.floor(love.math.random() * 360)/360*2*math.pi
		end
		a = b
		local m = n
		while m == n do
			m = love.math.random(1, #word)
		end
		n = m
	end
end
function love.draw()
	-- Sky
	love.graphics.setColor(0.15,0.050,0.025)
	love.graphics.rectangle('fill',0,0,w+16,h)
	-- Sun
	love.graphics.setColor(0.05,0,0)
	love.graphics.circle('fill',w/2,h/8,math.sqrt(w+h)*(((1+math.cos(sint*75))/50)+1))
	-- Ground
	love.graphics.setColor(0.075,0.1,0.075)
	love.graphics.rectangle('fill', 0, 10*24+3, w+16, h/2)
	-- March
	for i=-math.floor(w/8), 2*math.floor(w/8) do
		love.graphics.push()
		love.graphics.shear(-1,0)
		love.graphics.translate((sint*10)%16,0)
		if i%2==0 then
			--love.graphics.setColor(0.02,0.02,0.1)
			love.graphics.setColor(0.15,0.050,0.025)
		else 
			--love.graphics.setColor(0.1,0.1,0.13)
			love.graphics.setColor(0,0.01,0)
		end
		love.graphics.rectangle('fill', i*8, 10*24+3, 8, 12)
		love.graphics.pop()
	end
	-- Clocks
	love.graphics.setColor(0,0,0.025)
	-- Left
	local lcx,lcy,lr = (w+16)/12, h-h/12, math.sqrt(w+h)
	-- Face
	love.graphics.circle('line',lcx,lcy,lr)
	-- Ticks
	local lticks = 12
	for i=0,lticks do
		local angle = math.pi/2 + i/lticks*(math.pi*2)
		local x,y = math.cos(angle)*lr,math.sin(angle)*lr
		if i%3==0 then
			love.graphics.line(lcx-3*x/4,lcy-3*y/4,lcx-x,lcy-y)
		else
			love.graphics.line(lcx-6*x/7,lcy-6*y/7,lcx-x,lcy-y)
		end
	end
	--Hands
	local revhand = (sint*3) % math.pi*2
	local x,y = math.cos(revhand)*lr*0.9,math.sin(revhand)*lr*0.9
	love.graphics.line(lcx,lcy,lcx-x,lcy+y)
	-- Right
	local rcx, rcy, rr = (w+16)-(w+16)/12, h-h/12, math.sqrt(w+h)
	-- Face
	love.graphics.circle('line',rcx,rcy,rr)
	-- Ticks
	local rticks = 100
	for i=0,rticks do
		local angle = -0.34 + math.log(i/rticks*(math.pi*2))
		local x,y = math.cos(angle)*rr,math.sin(angle)*rr
		if i%3==0 then
			love.graphics.line(rcx-3*x/4,rcy-3*y/4,rcx-x,rcy-y)
		else
			love.graphics.line(rcx-6*x/7,rcy-6*y/7,rcx-x,rcy-y)
		end
	end
	-- Hands
	local chaohands = {}
	chaohands[1] = a
	chaohands[2] = a+a
	chaohands[3] = a*a
	chaohands[4] = a^a
	for i=1,#chaohands do
		local x,y = math.cos(chaohands[i])*rr*(0.9-(0.2*(i-1))),math.sin(chaohands[i])*rr*(0.9-(0.2*(i-1)))
		love.graphics.line(rcx,rcy,rcx-x,rcy-y)
	end
	-- Text
	love.graphics.setColor(0.75,0.75,0.9)
	local yofs = 0
	for i=1, #text do
		yofs = yofs + gaps[i]
		love.graphics.print(text[i]:format(word[n]), 8+(ofss[i]+math.sin(math.pi * sint + (i*(1/#text)))*80/lens[i]), yofs)
	end
end
function love.quit()
	-- Note that Win7 x64 always sets enterbutton to 2 and escapebutton to 3...
	local pressedbutton = love.window.showMessageBox(
		"STOP PROCRASTINATING!",
		"I wouldn't close it if i were you... we both know you need the encouragement. :3", 
		{"Wut is even?", "Yeah, i do.","No i don't.", enterbutton = 2, escapebutton = 3}, 
		"info",
		true
	)
	if pressedbutton == 3 then
		return false
	elseif pressedbutton == 2 then
		return true
	else
		return nil -- Suprises galore, i wonder what'll happen. :3
	end
end